// clkgen.v - master clock generator for I2S test
// E. Brombaugh - 08-26-2008
// modified by S. Gravenhorst
// @ 38.4 MHz >= 200.00 kHz sample rate (with divider of 192)
// expanded cnt to 10 bits to accomodate divider 768

module clkgen(clk, reset, rate);
	input clk;		// system clock
	input reset;	// POR
	output rate;	// Sample rate clock output
	
  parameter DIVIDER = 192;
  parameter N = DIVIDER - 1;

	// rate counter
	reg rate;
	reg [9:0] cnt;
	always @ ( posedge clk )
		if ( reset | rate ) cnt <= N;
		else                cnt <= cnt - 1;
	
	// detect end condition
	always @(posedge clk) rate <= (cnt == 10'd1);
endmodule
